@@ -276,8 +276,6 @@ def scan_i2c(
 
 def prove_max31865(spibus, cs):
     max31865_pt100 = MAX31865(spibus, cs)
-    if max31865_pt100.device is None:
-        return False
     if max31865_pt100.exists():
         return max31865_pt100
     return False
