@@ -10,6 +10,7 @@ Sensor Class for NAU7802
 import time
 from ...core.error import Error
 from ...core.sensor import I2CSensor
+
 # import logging
 # logging.basicConfig(level=logging.DEBUG)
 
@@ -18,14 +19,15 @@ class NAU7802(I2CSensor):
     """
     Qwiic Scale driver
     """
+
     __name__ = "NAU7802"
 
     _SENSOR_ADDRESS = 0x2A
 
     _units = {
         "adc": "[-]",
-        }
-    _i2c_freq = 100E3
+    }
+    _i2c_freq = 100e3
 
     # Register
     __REG = {
@@ -55,7 +57,7 @@ class NAU7802(I2CSensor):
         "OTP_B0": 0x17,  # OTP 15: 8
         "PGA": 0x1B,
         "PGA_PWR": 0x1C,
-        "DEVICE_REV": 0x1F
+        "DEVICE_REV": 0x1F,
     }
 
     __BIT = {
@@ -68,7 +70,7 @@ class NAU7802(I2CSensor):
             "CS": 4,
             "CR": 5,
             "OSCS": 6,
-            "AVDDS": 7
+            "AVDDS": 7,
         },
         # Bits within the CTRL2 register
         "CTRL2": {
@@ -77,7 +79,7 @@ class NAU7802(I2CSensor):
             "CALS": 2,
             "CAL_ERROR": 3,
             "CRS": 4,
-        }
+        },
     }
     # Bits within the PGA register
     __NAU7802_PGA_CHP_DIS = 0
@@ -94,37 +96,41 @@ class NAU7802(I2CSensor):
     __NAU7802_PGA_PWR_PGA_CAP_EN = 7
 
     # Allowed Low drop out regulator
-    __NAU7802_LDO_Voltage = {'2.4': 0b111,
-                             '2.7': 0b110,
-                             '3.0': 0b101,
-                             '3.3': 0b100,
-                             '3.6': 0b011,
-                             '3.9': 0b010,
-                             '4.2': 0b001,
-                             '4.5': 0b000}
+    __NAU7802_LDO_Voltage = {
+        "2.4": 0b111,
+        "2.7": 0b110,
+        "3.0": 0b101,
+        "3.3": 0b100,
+        "3.6": 0b011,
+        "3.9": 0b010,
+        "4.2": 0b001,
+        "4.5": 0b000,
+    }
 
     # Allowed gains
-    __NAU7802_GAIN = {'128': 0b111, '64': 0b110, '32': 0b101, '16': 0b100,
-                      '8': 0b011, '4': 0b010, '2': 0b001, '1': 0b000}
+    __NAU7802_GAIN = {
+        "128": 0b111,
+        "64": 0b110,
+        "32": 0b101,
+        "16": 0b100,
+        "8": 0b011,
+        "4": 0b010,
+        "2": 0b001,
+        "1": 0b000,
+    }
 
     # Allowed samples per second
-    __NAU7802_SPS = {
-            '320': 0b111,
-            '80': 0b011,
-            '40': 0b010,
-            '20': 0b001,
-            '10': 0b000}
+    __NAU7802_SPS = {"320": 0b111, "80": 0b011, "40": 0b010, "20": 0b001, "10": 0b000}
 
     # Select between channel values
     __NAU7802_CHANNEL_1 = 0
     __NAU7802_CHANNEL_2 = 1
 
     # Calibration state
-    __CAL_STATUS = {'SUCCESS': 0, 'IN PROGRESS': 1, 'FAILURE': 2}
+    __CAL_STATUS = {"SUCCESS": 0, "IN PROGRESS": 1, "FAILURE": 2}
 
     def __init__(self, *args, **kwargs):
-        """
-        """
+        """"""
         super().__init__(*args, **kwargs)
         self.exists = self.check_exists()
         self.offset_factor = None
@@ -146,9 +152,7 @@ class NAU7802(I2CSensor):
                 new_value = ((new_value << value) | 1) & 1
                 self._logger.debug("Set bit %s at register %s", value, address)
         else:
-            self._logger.warning("Failed to set bit %s at register %s",
-                                 value,
-                                 address)
+            self._logger.warning("Failed to set bit %s at register %s", value, address)
 
         return new_value
 
@@ -201,15 +205,17 @@ class NAU7802(I2CSensor):
         return False
 
     def get_data_rdy(self):
-        return bool(self.get_bit(self.__REG["PU_CTRL"],
-                                 self.__BIT["PU_CTRL"]["CR"]) == 1)
+        return bool(
+            self.get_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["CR"]) == 1
+        )
 
     def reset(self):
         self._logger.info("Reset...")
         rst = self.set_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["RR"])
         if rst is not None:
-            stop_rst = self.clear_bit(self.__REG["PU_CTRL"],
-                                      self.__BIT["PU_CTRL"]["RR"])
+            stop_rst = self.clear_bit(
+                self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["RR"]
+            )
             if stop_rst is not None:
                 return True
             else:
@@ -224,8 +230,7 @@ class NAU7802(I2CSensor):
         pua_status = True
 
         self.set_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["PUD"])
-        pud_status = self.get_bit(self.__REG["PU_CTRL"],
-                                  self.__BIT["PU_CTRL"]["PUD"])
+        pud_status = self.get_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["PUD"])
 
         if pud_status is not None:
             self._logger.info("Power up digital successfull.")
@@ -234,8 +239,7 @@ class NAU7802(I2CSensor):
             pua_status = False
 
         self.set_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["PUA"])
-        pua_status = self.get_bit(self.__REG["PU_CTRL"],
-                                  self.__BIT["PU_CTRL"]["PUA"])
+        pua_status = self.get_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["PUA"])
         if pua_status:
             self._logger.info("Power up analog successfull.")
         else:
@@ -253,17 +257,22 @@ class NAU7802(I2CSensor):
                 value += self.__NAU7802_LDO_Voltage[voltage] << 3
                 self.txrx([self.__REG["CTRL1"], value], readlen=0)
                 current_voltage = self.get_ldo_voltage()
-                self._logger.debug("LDO Voltage: Wrote %s (%s) Read %s",
-                                   voltage,
-                                   self.__NAU7802_LDO_Voltage[voltage],
-                                   current_voltage)
+                self._logger.debug(
+                    "LDO Voltage: Wrote %s (%s) Read %s",
+                    voltage,
+                    self.__NAU7802_LDO_Voltage[voltage],
+                    current_voltage,
+                )
                 if current_voltage == self.__NAU7802_LDO_Voltage[voltage]:
-                    self._logger.debug("Successfully set LDO Voltage: %s",
-                                       value)
+                    self._logger.debug("Successfully set LDO Voltage: %s", value)
                     return True
                 else:
-                    self._logger.warning("Failed to set LDO Voltage: Set: %s \
-                            Current: %s", value, current_voltage)
+                    self._logger.warning(
+                        "Failed to set LDO Voltage: Set: %s \
+                            Current: %s",
+                        value,
+                        current_voltage,
+                    )
                     return False
             else:
                 return False
@@ -288,8 +297,12 @@ class NAU7802(I2CSensor):
                 if current_gain == gain:
                     return True
                 else:
-                    self._logger.warning("Failed to set gain: Set: %s \
-                            Current: %s", value, current_gain)
+                    self._logger.warning(
+                        "Failed to set gain: Set: %s \
+                            Current: %s",
+                        value,
+                        current_gain,
+                    )
                     return False
             else:
                 return False
@@ -363,8 +376,7 @@ class NAU7802(I2CSensor):
 
     def begin_calibrate_afe(self):
         self._logger.info("Begin calibration of analog interface.")
-        return self.set_bit(self.__REG["CTRL2"],
-                            self.__BIT["CTRL2"]["CALS"]) == 1
+        return self.set_bit(self.__REG["CTRL2"], self.__BIT["CTRL2"]["CALS"]) == 1
 
     def check_calibration_status(self):
         return self.getU8(self.__REG["CTRL2"]) & 0b11
@@ -372,14 +384,14 @@ class NAU7802(I2CSensor):
     def wait_for_calibration(self, timeout_ms):
         calibration_begin = time.time()
         status = self.check_calibration_status()
-        while status == self.__CAL_STATUS['IN PROGRESS']:
+        while status == self.__CAL_STATUS["IN PROGRESS"]:
             delta_time = (calibration_begin - time.time()) * 1000
             self._logger.debug("Calib status: \t %s \t %s", status, delta_time)
             if delta_time > timeout_ms:
                 self._logger.error("Calibration timed out.")
                 break
             status = self.check_calibration_status()
-        if status == self.__CAL_STATUS['SUCCESS']:
+        if status == self.__CAL_STATUS["SUCCESS"]:
             return True
         else:
             return False
@@ -409,8 +421,7 @@ class NAU7802(I2CSensor):
         return res
 
     def enable_AVDDS(self):
-        res = self.set_bit(self.__REG["PU_CTRL"],
-                           self.__BIT["PU_CTRL"]["AVDDS"])
+        res = self.set_bit(self.__REG["PU_CTRL"], self.__BIT["PU_CTRL"]["AVDDS"])
         state = True
         if res == 0:
             self._logger.error("Failed to enable ACDDS")
@@ -456,12 +467,13 @@ class NAU7802(I2CSensor):
         self.calibrate()
         self._logger.debug("Re-Calibration %s", init_ok)
         # Turn off CLK_CHP. see manual 9.1 power on sequencing
-        init_ok &= (self.txrx([self.__REG["ADC"], 0x30]) is not None)
+        init_ok &= self.txrx([self.__REG["ADC"], 0x30]) is not None
         self._logger.debug("Set clock frequency %s", init_ok)
         # Enable 330pF decoupling cap on chan 2.
         # see manual 9.14 application circuit note
-        init_ok &= self.set_bit(self.__REG["PGA_PWR"],
-                                self.__NAU7802_PGA_PWR_PGA_CAP_EN) == 1
+        init_ok &= (
+            self.set_bit(self.__REG["PGA_PWR"], self.__NAU7802_PGA_PWR_PGA_CAP_EN) == 1
+        )
         self._logger.debug("Enable 330pF decoupling %s", init_ok)
         # Set samples per second
         init_ok &= self.set_sample_rate(sample_rate)
@@ -526,7 +538,7 @@ class NAU7802(I2CSensor):
                 self.reset()
             else:
                 self._logger.error("Sensor not  detected. %s", detect)
-            self.data['object'] = "ERROR"
+            self.data["object"] = "ERROR"
             return self.data
 
         if adc is None:
@@ -544,15 +556,12 @@ class NAU7802(I2CSensor):
             else:
                 self._logger.error("Sensor not  detected. %s", detect)
 
-            self.data['object'] = "ERROR"
+            self.data["object"] = "ERROR"
             return self.data
 
         if self.error is None:
             self.data["error"] = False
             self.data["values"] = {}
-            self.data["values"]["adc"] = {
-                'value': adc,
-                'unit': self._units['adc']
-                }
+            self.data["values"]["adc"] = {"value": adc, "unit": self._units["adc"]}
 
         return self.data
